pyessv
===============

Python earth system standard vocabularies.


What is ES-DOC ?
--------------------------------------

ES-DOC stands for Earth Science - Documentation.  It's goal is to provide software tools and services in order to support the distribution of earth science documentation.


What is pyessv ?
--------------------------------------

pyessv is a python client library for mamnaging vocabulries.  It supports vocabulary creation, validation, serialization, governance & I/O use cases.


Why pyessv ?
--------------------------------------

A documentation eco-system is only as good as the available vocabularies.  ES-DOC provides the pyessv client tool so as to simplify leveraging the ES-DOC eco-ssytem in the python programming language.


Who uses pyessv ?
--------------------------------------

Developers building value added software ontop of the ES-DOC eco-system.


Further Information ?
--------------------------------------

See http:es-doc.org.